aggr_data: Data used by the app if database is not used

Description Usage Format

Description

Data used by the app if database is not used

Usage

1

Format

An object of class list of length 5.


mong/qmongr documentation built on May 23, 2021, 6:37 a.m.